use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Caron
Casey
Champoux
Chase
David
Email
Michael
NNTP
Qmail
Ricardo
SIGNES
SMTP
Send
Sendmail
Signes
Steinbrunner
Test
UserAgent
West
Whitener
Yanick
achtung
bcc
capoeirab
casey
dsteinbrunner
lib
michael
qmail
rjbs
sasl
yanick
